@@ -30,6 +30,7 @@
 
 #include "common/gkr-buffer.h"
 #include "common/gkr-secure-memory.h"
+#include "common/gkr-unix-credentials.h"
 
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -92,11 +93,11 @@ static char socket_path[1024] = { 0, };
 static int slot_id = 0;
 
 #ifndef ASSERT
-#  ifdef _DEBUG
+#  ifdef G_DISABLE_ASSERT
+#    define ASSERT(x)
+#  else
 #    include <assert.h>
 #    define ASSERT(x) assert(x)
-#  else
-#    define ASSERT(x)
 #  endif 
 #endif
 
@@ -125,7 +126,7 @@ gkr_pkcs11_warn (const char* msg, ...)
 	va_end (va);
 }
 
-#ifdef _xDEBUG 
+#ifdef _DEBUG 
 
 static void 
 gkr_pkcs11_debug (const char* msg, ...)
@@ -295,7 +296,7 @@ call_session_connect (CallSession *cs)
 	ASSERT (pkcs11_initialized);
 	
 	/* Yup, no environment variable == no token */
-	if (!socket_path || !socket_path[0]) {
+	if (!socket_path[0]) {
 		WARN (("S%d: no socket available to connect session to"));
 		return CKR_TOKEN_NOT_PRESENT;
 	}
@@ -327,10 +328,17 @@ call_session_connect (CallSession *cs)
 		return CKR_DEVICE_ERROR;
 	}
 
+	if (gkr_unix_credentials_write (sock) < 0) {
+		close (sock);
+		WARN (("S%d: couldn't send socket credentials: %s", 
+		       cs->id, strerror (errno)));
+		return CKR_DEVICE_ERROR;
+	}
+
 	cs->socket = sock;
 	cs->call_state = CALL_READY;
-	
 	DBG (("S%d: connected", cs->id));
+	
 	return CKR_OK;
 }
 
@@ -1793,9 +1801,12 @@ gkr_C_CancelFunction (CK_SESSION_HANDLE hSession)
 	_ret = proto_read_uint32_array (_cs->resp, (a), (n), (mx)); \
 	if (_ret != CKR_OK) goto _cleanup;
 
-#define OUT_RETURN_CODE() \
-	_ret = gkr_pkcs11_message_read_uint32 (_cs->resp, (_ret == CKR_OK) ? &_ret : NULL); \
-	if (_ret != CKR_OK) goto _cleanup;
+#define OUT_RETURN_CODE() { \
+	CK_RV r; \
+	_ret = gkr_pkcs11_message_read_uint32 (_cs->resp, (_ret == CKR_OK) ? &r : NULL); \
+	if (_ret == CKR_OK) _ret = r; \
+	if (_ret != CKR_OK) goto _cleanup; \
+	}
 
 #define OUT_SESSION_INFO(info) \
 	_ret = proto_read_sesssion_info (_cs->resp, info); \
@@ -1944,8 +1955,8 @@ gkr_C_SetAttributeValue (CK_SESSION_HANDLE session, CK_OBJECT_HANDLE object,
 {
 	BEGIN_CALL (session, C_SetAttributeValue);
 		IN_HANDLE (object);
-	PROCESS_CALL;
 		IN_ATTRIBUTE_ARRAY (template, count);
+	PROCESS_CALL;
 	END_CALL;
 }
 
